==> cfbfastR_1.9.0.tar.gz: cfbfastR/tests/testthat/test-espn_cfb_team_stats.R <==

test_that("ESPN CFB Team Stats", {
  skip_on_cran()

  cols <- c(
    "general_fumbles",
    "general_fumbles_lost",
    "general_fumbles_forced",
    "general_fumbles_recovered",
    "general_fumbles_touchdowns",
    "general_games_played",
    "general_offensive_two_pt_returns",
    "general_offensive_fumbles_touchdowns",
    "general_defensive_fumbles_touchdowns",
    "passing_avg_gain",
    "passing_completion_pct",
    "passing_completions",
    "passing_espnqb_rating",
    "passing_interception_pct",
    "passing_interceptions",
    "passing_long_passing",
    "passing_misc_yards",
    "passing_net_passing_yards",
    "passing_net_passing_yards_per_game",
    "passing_net_total_yards",
    "passing_net_yards_per_game",
    "passing_passing_attempts",
    "passing_passing_big_plays",
    "passing_passing_first_downs",
    "passing_passing_fumbles",
    "passing_passing_fumbles_lost",
    "passing_passing_touchdown_pct",
    "passing_passing_touchdowns",
    "passing_passing_yards",
    "passing_passing_yards_after_catch",
    "passing_passing_yards_at_catch",
    "passing_passing_yards_per_game",
    "passing_qb_rating",
    "passing_sacks",
    "passing_sack_yards_lost",
    "passing_team_games_played",
    "passing_total_offensive_plays",
    "passing_total_points",
    "passing_total_points_per_game",
    "passing_total_touchdowns",
    "passing_total_yards",
    "passing_total_yards_from_scrimmage",
    "passing_two_point_pass_convs",
    "passing_two_pt_pass",
    "passing_two_pt_pass_attempts",
    "passing_yards_from_scrimmage_per_game",
    "passing_yards_per_completion",
    "passing_yards_per_game",
    "passing_yards_per_pass_attempt",
    "passing_net_yards_per_pass_attempt",
    "passing_quarterback_rating",
    "rushing_avg_gain",
    "rushing_espnrb_rating",
    "rushing_long_rushing",
    "rushing_misc_yards",
    "rushing_net_total_yards",
    "rushing_net_yards_per_game",
    "rushing_rushing_attempts",
    "rushing_rushing_big_plays",
    "rushing_rushing_first_downs",
    "rushing_rushing_fumbles",
    "rushing_rushing_fumbles_lost",
    "rushing_rushing_touchdowns",
    "rushing_rushing_yards",
    "rushing_rushing_yards_per_game",
    "rushing_stuffs",
    "rushing_stuff_yards_lost",
    "rushing_team_games_played",
    "rushing_total_offensive_plays",
    "rushing_total_points",
    "rushing_total_points_per_game",
    "rushing_total_touchdowns",
    "rushing_total_yards",
    "rushing_total_yards_from_scrimmage",
    "rushing_two_point_rush_convs",
    "rushing_two_pt_rush",
    "rushing_two_pt_rush_attempts",
    "rushing_yards_from_scrimmage_per_game",
    "rushing_yards_per_game",
    "rushing_yards_per_rush_attempt",
    "receiving_avg_gain",
    "receiving_espnwr_rating",
    "receiving_long_reception",
    "receiving_misc_yards",
    "receiving_net_total_yards",
    "receiving_net_yards_per_game",
    "receiving_receiving_big_plays",
    "receiving_receiving_first_downs",
    "receiving_receiving_fumbles",
    "receiving_receiving_fumbles_lost",
    "receiving_receiving_targets",
    "receiving_receiving_touchdowns",
    "receiving_receiving_yards",
    "receiving_receiving_yards_after_catch",
    "receiving_receiving_yards_at_catch",
    "receiving_receiving_yards_per_game",
    "receiving_receptions",
    "receiving_team_games_played",
    "receiving_total_offensive_plays",
    "receiving_total_points",
    "receiving_total_points_per_game",
    "receiving_total_touchdowns",
    "receiving_total_yards",
    "receiving_total_yards_from_scrimmage",
    "receiving_two_point_rec_convs",
    "receiving_two_pt_reception",
    "receiving_two_pt_reception_attempts",
    "receiving_yards_from_scrimmage_per_game",
    "receiving_yards_per_game",
    "receiving_yards_per_reception",
    "defensive_assist_tackles",
    "defensive_avg_interception_yards",
    "defensive_avg_sack_yards",
    "defensive_avg_stuff_yards",
    "defensive_blocked_field_goal_touchdowns",
    "defensive_blocked_punt_touchdowns",
    "defensive_defensive_touchdowns",
    "defensive_hurries",
    "defensive_kicks_blocked",
    "defensive_long_interception",
    "defensive_misc_touchdowns",
    "defensive_passes_batted_down",
    "defensive_passes_defended",
    "defensive_two_pt_returns",
    "defensive_sacks",
    "defensive_sack_yards",
    "defensive_safeties",
    "defensive_solo_tackles",
    "defensive_stuffs",
    "defensive_stuff_yards",
    "defensive_tackles_for_loss",
    "defensive_team_games_played",
    "defensive_total_tackles",
    "defensive_yards_allowed",
    "defensive_points_allowed",
    "defensive_one_pt_safeties_made",
    "defensive_interceptions_interceptions",
    "defensive_interceptions_interception_touchdowns",
    "defensive_interceptions_interception_yards",
    "kicking_avg_kickoff_return_yards",
    "kicking_avg_kickoff_yards",
    "kicking_extra_point_attempts",
    "kicking_extra_point_pct",
    "kicking_extra_points_blocked",
    "kicking_extra_points_blocked_pct",
    "kicking_extra_points_made",
    "kicking_fair_catches",
    "kicking_fair_catch_pct",
    "kicking_field_goal_attempts",
    "kicking_field_goal_attempts1_19",
    "kicking_field_goal_attempts20_29",
    "kicking_field_goal_attempts30_39",
    "kicking_field_goal_attempts40_49",
    "kicking_field_goal_attempts50_59",
    "kicking_field_goal_attempts60_99",
    "kicking_field_goal_attempts50",
    "kicking_field_goal_attempt_yards",
    "kicking_field_goal_pct",
    "kicking_field_goals_blocked",
    "kicking_field_goals_blocked_pct",
    "kicking_field_goals_made",
    "kicking_field_goals_made1_19",
    "kicking_field_goals_made20_29",
    "kicking_field_goals_made30_39",
    "kicking_field_goals_made40_49",
    "kicking_field_goals_made50_59",
    "kicking_field_goals_made60_99",
    "kicking_field_goals_made50",
    "kicking_field_goals_made_yards",
    "kicking_field_goals_missed_yards",
    "kicking_kickoff_returns",
    "kicking_kickoff_return_touchdowns",
    "kicking_kickoff_return_yards",
    "kicking_kickoffs",
    "kicking_kickoff_yards",
    "kicking_long_field_goal_attempt",
    "kicking_long_field_goal_made",
    "kicking_long_kickoff",
    "kicking_team_games_played",
    "kicking_total_kicking_points",
    "kicking_touchback_pct",
    "kicking_touchbacks",
    "returning_def_fumble_returns",
    "returning_def_fumble_return_yards",
    "returning_fumble_recoveries",
    "returning_fumble_recovery_yards",
    "returning_kick_return_fair_catches",
    "returning_kick_return_fair_catch_pct",
    "returning_kick_return_fumbles",
    "returning_kick_return_fumbles_lost",
    "returning_kick_returns",
    "returning_kick_return_touchdowns",
    "returning_kick_return_yards",
    "returning_long_kick_return",
    "returning_long_punt_return",
    "returning_misc_fumble_returns",
    "returning_misc_fumble_return_yards",
    "returning_opp_fumble_recoveries",
    "returning_opp_fumble_recovery_yards",
    "returning_opp_special_team_fumble_returns",
    "returning_opp_special_team_fumble_return_yards",
    "returning_punt_return_fair_catches",
    "returning_punt_return_fair_catch_pct",
    "returning_punt_return_fumbles",
    "returning_punt_return_fumbles_lost",
    "returning_punt_returns",
    "returning_punt_returns_started_inside_the10",
    "returning_punt_returns_started_inside_the20",
    "returning_punt_return_touchdowns",
    "returning_punt_return_yards",
    "returning_special_team_fumble_returns",
    "returning_special_team_fumble_return_yards",
    "returning_team_games_played",
    "returning_yards_per_kick_return",
    "returning_yards_per_punt_return",
    "returning_yards_per_return",
    "punting_avg_punt_return_yards",
    "punting_fair_catches",
    "punting_gross_avg_punt_yards",
    "punting_long_punt",
    "punting_net_avg_punt_yards",
    "punting_punt_returns",
    "punting_punt_return_yards",
    "punting_punts",
    "punting_punts_blocked",
    "punting_punts_blocked_pct",
    "punting_punts_inside10",
    "punting_punts_inside10pct",
    "punting_punts_inside20",
    "punting_punts_inside20pct",
    "punting_punt_yards",
    "punting_team_games_played",
    "punting_touchback_pct",
    "punting_touchbacks",
    "scoring_defensive_points",
    "scoring_field_goals",
    "scoring_kick_extra_points",
    "scoring_misc_points",
    "scoring_passing_touchdowns",
    "scoring_receiving_touchdowns",
    "scoring_return_touchdowns",
    "scoring_rushing_touchdowns",
    "scoring_total_points",
    "scoring_total_points_per_game",
    "scoring_total_touchdowns",
    "scoring_total_two_point_convs",
    "scoring_two_point_pass_convs",
    "scoring_two_point_rec_convs",
    "scoring_two_point_rush_convs",
    "scoring_one_pt_safeties_made",
    "miscellaneous_first_downs",
    "miscellaneous_first_downs_passing",
    "miscellaneous_first_downs_penalty",
    "miscellaneous_first_downs_per_game",
    "miscellaneous_first_downs_rushing",
    "miscellaneous_fourth_down_attempts",
    "miscellaneous_fourth_down_conv_pct",
    "miscellaneous_fourth_down_convs",
    "miscellaneous_fumbles_lost",
    "miscellaneous_possession_time_seconds",
    "miscellaneous_redzone_efficiency_pct",
    "miscellaneous_redzone_field_goal_pct",
    "miscellaneous_redzone_scoring_pct",
    "miscellaneous_redzone_touchdown_pct",
    "miscellaneous_third_down_attempts",
    "miscellaneous_third_down_conv_pct",
    "miscellaneous_third_down_convs",
    "miscellaneous_total_giveaways",
    "miscellaneous_total_penalties",
    "miscellaneous_total_penalty_yards",
    "miscellaneous_total_takeaways",
    "miscellaneous_total_drives",
    "miscellaneous_turn_over_differential"
  )

  x <- espn_cfb_team_stats(2020, team_id = 57)

  y <- espn_cfb_team_stats(2020, team_id = 52)

  expect_equal(sort(colnames(x)), sort(cols))
  expect_equal(sort(colnames(y)), sort(cols))
  expect_s3_class(x, "data.frame")
  expect_s3_class(y, "data.frame")
})

==> cfbfastR_2.0.0.tar.gz: cfbfastR/tests/testthat/test-espn_cfb_team_stats.R <==

test_that("ESPN CFB Team Stats", {
  skip_on_cran()

  cols <- c(
    "team_id",
    "team_guid",
    "team_uid",
    "team_sdr",
    "team_slug",
    "team_location",
    "team_name",
    "team_nickname",
    "team_abbreviation",
    "team_display_name",
    "team_short_display_name",
    "team_color",
    "team_alternate_color",
    "is_active",
    "is_all_star",
    "logo_href",
    "logo_dark_href",
    "logos_href_2",
    "logos_rel_primary_logo_on_white_color",
    "logos_href_3",
    "logos_rel_primary_logo_on_black_color",
    "logos_href_4",
    "logos_width_4",
    "logos_height_4",
    "logos_alt_4",
    "logos_rel_full_4",
    "logos_rel_primary_logo_on_primary_color",
    "logos_last_updated_4",
    "logos_href_5",
    "logos_width_5",
    "logos_height_5",
    "logos_alt_5",
    "logos_rel_full_5",
    "logos_rel_primary_logo_on_secondary_color",
    "logos_last_updated_5",
    "logos_href_6",
    "logos_width_6",
    "logos_height_6",
    "logos_alt_6",
    "logos_rel_full_6",
    "logos_rel_secondary_logo_on_white_color",
    "logos_last_updated_6",
    "logos_href_7",
    "logos_width_7",
    "logos_height_7",
    "logos_alt_7",
    "logos_rel_full_7",
    "logos_rel_secondary_logo_on_black_color",
    "logos_last_updated_7",
    "logos_href_8",
    "logos_width_8",
    "logos_height_8",
    "logos_alt_8",
    "logos_rel_full_8",
    "logos_rel_secondary_logo_on_primary_color",
    "logos_last_updated_8",
    "logos_href_9",
    "logos_width_9",
    "logos_height_9",
    "logos_alt_9",
    "logos_rel_full_9",
    "logos_rel_secondary_logo_on_secondary_color",
    "logos_last_updated_9",
    "general_fumbles",
    "general_fumbles_lost",
    "general_fumbles_forced",
    "general_fumbles_recovered",
    "general_fumbles_touchdowns",
    "general_games_played",
    "general_offensive_two_pt_returns",
    "general_offensive_fumbles_touchdowns",
    "general_defensive_fumbles_touchdowns",
    "general_total_penalties",
    "general_total_penalty_yards",
    "passing_avg_gain",
    "passing_completion_pct",
    "passing_completions",
    "passing_espnqb_rating",
    "passing_interception_pct",
    "passing_interceptions",
    "passing_long_passing",
    "passing_misc_yards",
    "passing_net_passing_yards",
    "passing_net_passing_yards_per_game",
    "passing_net_total_yards",
    "passing_net_yards_per_game",
    "passing_passing_attempts",
    "passing_passing_big_plays",
    "passing_passing_first_downs",
    "passing_passing_fumbles",
    "passing_passing_fumbles_lost",
    "passing_passing_touchdown_pct",
    "passing_passing_touchdowns",
    "passing_passing_yards",
    "passing_passing_yards_after_catch",
    "passing_passing_yards_at_catch",
    "passing_passing_yards_per_game",
    "passing_qb_rating",
    "passing_sacks",
    "passing_sack_yards_lost",
    "passing_team_games_played",
    "passing_total_offensive_plays",
    "passing_total_points",
    "passing_total_points_per_game",
    "passing_total_touchdowns",
    "passing_total_yards",
    "passing_total_yards_from_scrimmage",
    "passing_two_point_pass_convs",
    "passing_two_pt_pass",
    "passing_two_pt_pass_attempts",
    "passing_yards_from_scrimmage_per_game",
    "passing_yards_per_completion",
    "passing_yards_per_game",
    "passing_yards_per_pass_attempt",
    "passing_net_yards_per_pass_attempt",
    "passing_quarterback_rating",
    "rushing_avg_gain",
    "rushing_espnrb_rating",
    "rushing_long_rushing",
    "rushing_misc_yards",
    "rushing_net_total_yards",
    "rushing_net_yards_per_game",
    "rushing_rushing_attempts",
    "rushing_rushing_big_plays",
    "rushing_rushing_first_downs",
    "rushing_rushing_fumbles",
    "rushing_rushing_fumbles_lost",
    "rushing_rushing_touchdowns",
    "rushing_rushing_yards",
    "rushing_rushing_yards_per_game",
    "rushing_stuffs",
    "rushing_stuff_yards_lost",
    "rushing_team_games_played",
    "rushing_total_offensive_plays",
    "rushing_total_points",
    "rushing_total_points_per_game",
    "rushing_total_touchdowns",
    "rushing_total_yards",
    "rushing_total_yards_from_scrimmage",
    "rushing_two_point_rush_convs",
    "rushing_two_pt_rush",
    "rushing_two_pt_rush_attempts",
    "rushing_yards_from_scrimmage_per_game",
    "rushing_yards_per_game",
    "rushing_yards_per_rush_attempt",
    "receiving_avg_gain",
    "receiving_espnwr_rating",
    "receiving_long_reception",
    "receiving_misc_yards",
    "receiving_net_total_yards",
    "receiving_net_yards_per_game",
    "receiving_receiving_big_plays",
    "receiving_receiving_first_downs",
    "receiving_receiving_fumbles",
    "receiving_receiving_fumbles_lost",
    "receiving_receiving_targets",
    "receiving_receiving_touchdowns",
    "receiving_receiving_yards",
    "receiving_receiving_yards_after_catch",
    "receiving_receiving_yards_at_catch",
    "receiving_receiving_yards_per_game",
    "receiving_receptions",
    "receiving_team_games_played",
    "receiving_total_offensive_plays",
    "receiving_total_points",
    "receiving_total_points_per_game",
    "receiving_total_touchdowns",
    "receiving_total_yards",
    "receiving_total_yards_from_scrimmage",
    "receiving_two_point_rec_convs",
    "receiving_two_pt_reception",
    "receiving_two_pt_reception_attempts",
    "receiving_yards_from_scrimmage_per_game",
    "receiving_yards_per_game",
    "receiving_yards_per_reception",
    "defensive_assist_tackles",
    "defensive_avg_interception_yards",
    "defensive_avg_sack_yards",
    "defensive_avg_stuff_yards",
    "defensive_blocked_field_goal_touchdowns",
    "defensive_blocked_punt_touchdowns",
    "defensive_defensive_touchdowns",
    "defensive_hurries",
    "defensive_kicks_blocked",
    "defensive_long_interception",
    "defensive_misc_touchdowns",
    "defensive_passes_batted_down",
    "defensive_passes_defended",
    "defensive_two_pt_returns",
    "defensive_sacks",
    "defensive_sack_yards",
    "defensive_safeties",
    "defensive_solo_tackles",
    "defensive_stuffs",
    "defensive_stuff_yards",
    "defensive_tackles_for_loss",
    "defensive_team_games_played",
    "defensive_total_tackles",
    "defensive_yards_allowed",
    "defensive_points_allowed",
    "defensive_one_pt_safeties_made",
    "defensive_missed_field_goal_return_td",
    "defensive_blocked_punt_ez_rec_td",
    "defensive_interceptions_interceptions",
    "defensive_interceptions_interception_touchdowns",
    "defensive_interceptions_interception_yards",
    "kicking_avg_kickoff_return_yards",
    "kicking_avg_kickoff_yards",
    "kicking_extra_point_attempts",
    "kicking_extra_point_pct",
    "kicking_extra_points_blocked",
    "kicking_extra_points_blocked_pct",
    "kicking_extra_points_made",
    "kicking_fair_catches",
    "kicking_fair_catch_pct",
    "kicking_field_goal_attempts",
    "kicking_field_goal_attempts1_19",
    "kicking_field_goal_attempts20_29",
    "kicking_field_goal_attempts30_39",
    "kicking_field_goal_attempts40_49",
    "kicking_field_goal_attempts50_59",
    "kicking_field_goal_attempts60_99",
    "kicking_field_goal_attempts50",
    "kicking_field_goal_attempt_yards",
    "kicking_field_goal_pct",
    "kicking_field_goals_blocked",
    "kicking_field_goals_blocked_pct",
    "kicking_field_goals_made",
    "kicking_field_goals_made1_19",
    "kicking_field_goals_made20_29",
    "kicking_field_goals_made30_39",
    "kicking_field_goals_made40_49",
    "kicking_field_goals_made50_59",
    "kicking_field_goals_made60_99",
    "kicking_field_goals_made50",
    "kicking_field_goals_made_yards",
    "kicking_field_goals_missed_yards",
    "kicking_kickoff_returns",
    "kicking_kickoff_return_touchdowns",
    "kicking_kickoff_return_yards",
    "kicking_kickoffs",
    "kicking_kickoff_yards",
    "kicking_long_field_goal_attempt",
    "kicking_long_field_goal_made",
    "kicking_long_kickoff",
    "kicking_team_games_played",
    "kicking_total_kicking_points",
    "kicking_touchback_pct",
    "kicking_touchbacks",
    "returning_def_fumble_returns",
    "returning_def_fumble_return_yards",
    "returning_fumble_recoveries",
    "returning_fumble_recovery_yards",
    "returning_kick_return_fair_catches",
    "returning_kick_return_fair_catch_pct",
    "returning_kick_return_fumbles",
    "returning_kick_return_fumbles_lost",
    "returning_kick_returns",
    "returning_kick_return_touchdowns",
    "returning_kick_return_yards",
    "returning_long_kick_return",
    "returning_long_punt_return",
    "returning_misc_fumble_returns",
    "returning_misc_fumble_return_yards",
    "returning_opp_fumble_recoveries",
    "returning_opp_fumble_recovery_yards",
    "returning_opp_special_team_fumble_returns",
    "returning_opp_special_team_fumble_return_yards",
    "returning_punt_return_fair_catches",
    "returning_punt_return_fair_catch_pct",
    "returning_punt_return_fumbles",
    "returning_punt_return_fumbles_lost",
    "returning_punt_returns",
    "returning_punt_returns_started_inside_the10",
    "returning_punt_returns_started_inside_the20",
    "returning_punt_return_touchdowns",
    "returning_punt_return_yards",
    "returning_special_team_fumble_returns",
    "returning_special_team_fumble_return_yards",
    "returning_team_games_played",
    "returning_yards_per_kick_return",
    "returning_yards_per_punt_return",
    "returning_yards_per_return",
    "punting_avg_punt_return_yards",
    "punting_fair_catches",
    "punting_gross_avg_punt_yards",
    "punting_long_punt",
    "punting_net_avg_punt_yards",
    "punting_punt_returns",
    "punting_punt_return_yards",
    "punting_punts",
    "punting_punts_blocked",
    "punting_punts_blocked_pct",
    "punting_punts_inside10",
    "punting_punts_inside10pct",
    "punting_punts_inside20",
    "punting_punts_inside20pct",
    "punting_punt_yards",
    "punting_team_games_played",
    "punting_touchback_pct",
    "punting_touchbacks",
    "scoring_defensive_points",
    "scoring_field_goals",
    "scoring_kick_extra_points",
    "scoring_kick_extra_points_made",
    "scoring_misc_points",
    "scoring_passing_touchdowns",
    "scoring_receiving_touchdowns",
    "scoring_return_touchdowns",
    "scoring_rushing_touchdowns",
    "scoring_total_points",
    "scoring_total_points_per_game",
    "scoring_total_touchdowns",
    "scoring_total_two_point_convs",
    "scoring_two_point_pass_convs",
    "scoring_two_point_rec_convs",
    "scoring_two_point_rush_convs",
    "scoring_one_pt_safeties_made",
    "miscellaneous_first_downs",
    "miscellaneous_first_downs_passing",
    "miscellaneous_first_downs_penalty",
    "miscellaneous_first_downs_per_game",
    "miscellaneous_first_downs_rushing",
    "miscellaneous_fourth_down_attempts",
    "miscellaneous_fourth_down_conv_pct",
    "miscellaneous_fourth_down_convs",
    "miscellaneous_fumbles_lost",
    "miscellaneous_possession_time_seconds",
    "miscellaneous_redzone_efficiency_pct",
    "miscellaneous_redzone_field_goal_pct",
    "miscellaneous_redzone_scoring_pct",
    "miscellaneous_redzone_touchdown_pct",
    "miscellaneous_third_down_attempts",
    "miscellaneous_third_down_conv_pct",
    "miscellaneous_third_down_convs",
    "miscellaneous_total_giveaways",
    "miscellaneous_total_penalties",
    "miscellaneous_total_penalty_yards",
    "miscellaneous_total_takeaways",
    "miscellaneous_total_drives",
    "miscellaneous_turn_over_differential"
  )

  x <- espn_cfb_team_stats(2020, team_id = 57)

  y <- espn_cfb_team_stats(2020, team_id = 52)

  expect_setequal(sort(colnames(x)), sort(cols))
  expect_setequal(sort(colnames(y)), sort(cols))
  expect_s3_class(x, "data.frame")
  expect_s3_class(y, "data.frame")
})
